@@ -3,10 +3,10 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 use Data::Dumper;
-use List::Util qw(shuffle);
+use List::Util qw(shuffle max);
 use Getopt::EX::Colormap qw(colorize ansi_code);
 use Text::VisualWidth::PP 0.05 'vwidth';
 use App::Greple::wordle::word_all    qw(%word_all);
@@ -28,99 +28,102 @@ use Getopt::EX::Hashed; {
 }
 no Getopt::EX::Hashed;
 
-sub parseopt {
-    my $app = shift;
-    my $argv = shift;
-    use Getopt::Long qw(GetOptionsFromArray Configure);
-    Configure qw(bundling no_getopt_compat pass_through);
-    $app->getopt($argv) || die "Option parse error.\n";
-}
-
 sub _days {
     use Date::Calc qw(Delta_Days);
     my($mday, $mon, $year, $yday) = (localtime(time))[3,4,5,7];
     Delta_Days(2021, 6, 19, $year + 1900, $mon + 1, $mday);
 }
 
-sub get_index {
+sub parseopt {
     my $app = shift;
-    local $_ = $app->{index};
-    $_   = int rand @word_hidden if $app->{random};
-    $_ //= _days;
-    $_  += _days if /^[-+]/;
-    $_;
+    my $argv = shift;
+    use Getopt::Long qw(GetOptionsFromArray Configure);
+    Configure qw(bundling no_getopt_compat pass_through);
+    $app->getopt($argv) || die "Option parse error.\n";
+    $app;
 }
 
-######################################################################
-
-my $app = __PACKAGE__->new or die;
-my $game;
-
-sub initialize {
-    my($mod, $argv) = @_;
-    $app->parseopt($argv);
-
-    my $answer = make_answer();
-    $game = App::Greple::wordle::game->new(answer => $answer);
-
-    push @$argv, wordle_patterns($answer);
-    push @$argv, '--interactive', ('/dev/stdin') x $app->{total}
-	if -t STDIN;
-}
-
-sub respond {
-    local $_ = $_;
-    my $chomped = chomp;
-    use List::Util qw(max);
-    print ansi_code("{CHA}{CUU}") if $chomped;
-    print ansi_code(sprintf("{CHA}{CUF(%d)}", max(8, vwidth($_) + 2)));
-    print s/(?<=.)\z/\n/r for @_;
-}
-
-sub make_answer {
-    if ($app->{series} > 0) {
-	srand($app->{series});
-	@word_hidden = shuffle @word_hidden;
+sub setup {
+    my $app = shift;
+    for ($app->{index}) {
+	$_   = int rand @word_hidden if $app->{random};
+	$_ //= _days;
+	$_  += _days if /^[-+]/;
+    }
+    if (my $answer = $app->{answer}) {
+	$app->{series} = $app->{index} = 99999;
+	$answer =~ /^[a-z]{5}$/i or die "$answer: wrong word\n";
+    } else {
+	if ($app->{series} > 0) {
+	    srand($app->{series});
+	    @word_hidden = shuffle @word_hidden;
+	}
+	$app->{answer} = $word_hidden[ $app->{index} ];
     }
-    my $answer = $app->{answer};
-    $answer ||= $word_hidden[ $app->get_index ];
-    $answer =~ /^[a-z]{5}$/i or die "$answer: wrong word\n";
-    return $answer;
 }
 
-sub wordle_patterns {
-    my $answer = shift;
+sub patterns {
+    my $app = shift;
+    my $answer = $app->{answer};
     my @re = map
 	    { sprintf "(?<=^.{%d})%s", $_, substr($answer, $_, 1) }
 	    0 .. length($answer) - 1;
     my $green  = join '|', @re;
     my $yellow = "[$answer]";
     my $black  = "(?=[a-z])[^$answer]";
-
     map { ( '--re' => $_ ) } $green, $yellow, $black;
 }
 
+sub title {
+    my $app = shift;
+    sprintf('%s %s%s',
+	    'Greple::wordle',
+	    $app->{series} == 0 ? '' : sprintf("%d-", $app->{series}),
+	    $app->{index});
+}
+
+######################################################################
+
+my $app = __PACKAGE__->new or die;
+my $game;
+my $interactive;
+
+sub initialize {
+    my($mod, $argv) = @_;
+    $app->parseopt($argv)->setup;
+    $game = App::Greple::wordle::game->new(answer => $app->{answer});
+    push @$argv, $app->patterns;
+    if ($interactive = -t STDIN) {
+	push @$argv, '--interactive', ('/dev/stdin') x $app->{total};
+    }
+    say $app->title;
+}
+
+sub respond {
+    local $_ = $_;
+    my $chomped = chomp;
+    print ansi_code("{CHA}{CUU}") if $chomped;
+    print ansi_code(sprintf("{CHA}{CUF(%d)}", max(8, vwidth($_) + 2)));
+    print s/(?<=.)\z/\n/r for @_;
+}
+
 sub show_answer {
     say colorize('#6aaa64', uc $game->answer);
 }
 
 sub show_result {
-    printf("\n%s %s%s %d/%d\n\n",
-	   'Greple::wordle',
-	   $app->{series} == 0 ? '' : sprintf("%d-", $app->{series}),
-	   $app->get_index,
-	   $game->attempt, $app->{try});
+    printf "\n%s %d/%d\n\n", $app->title, $game->attempt, $app->{try};
     say $game->result;
 }
 
 sub check {
-    my $it = lc s/\n//r;
-    if (not $word_all{$it}) {
+    my $word = lc s/\n//r;
+    if (not $word_all{$word}) {
 	respond $app->{wrong};
 	$_ = '';
     } else {
-	$game->try($it);
-	print ansi_code '{CUU}' if -t STDIN;
+	$game->try($word);
+	print ansi_code '{CUU}' if $interactive;
     }
 }
 
